@@ -3,7 +3,7 @@
 from decimal import Decimal
 from collections import defaultdict
 
-from sql import Column
+from sql import Column, Literal, Null
 from sql.aggregate import Sum
 from sql.conditionals import Coalesce
 
@@ -18,10 +18,6 @@ from trytond.pool import Pool
 
 from .exceptions import AccountValidationError
 
-__all__ = ['Account', 'AccountDistribution',
-    'OpenChartAccountStart', 'OpenChartAccount',
-    'AnalyticAccountEntry', 'AnalyticMixin']
-
 
 class Account(
         DeactivableMixin, tree('distribution_parents'), tree(),
@@ -192,7 +188,7 @@ class Account(
                 Sum(Coalesce(line.credit, 0) - Coalesce(line.debit, 0)),
                 where=(table.type != 'view')
                 & table.id.in_(all_ids)
-                & (table.active == True) & line_query,
+                & (table.active == Literal(True)) & line_query,
                 group_by=table.id))
         account_sum = defaultdict(Decimal)
         for account_id, value in cursor.fetchall():
@@ -246,7 +242,7 @@ class Account(
                 ).select(*columns,
                 where=(table.type != 'view')
                 & table.id.in_(ids)
-                & (table.active == True) & line_query,
+                & (table.active == Literal(True)) & line_query,
                 group_by=table.id))
 
         for row in cursor.fetchall():
@@ -390,14 +386,13 @@ class AnalyticAccountEntry(ModelView, ModelSQL):
     def __register__(cls, module_name):
         pool = Pool()
         Account = pool.get('analytic_account.account')
-        TableHandler = backend.get('TableHandler')
         cursor = Transaction().connection.cursor()
 
         # Migration from 3.4: use origin as the key for One2Many
         migration_3_4 = False
         old_table = 'analytic_account_account_selection_rel'
-        if TableHandler.table_exist(old_table):
-            TableHandler.table_rename(old_table, cls._table)
+        if backend.TableHandler.table_exist(old_table):
+            backend.TableHandler.table_rename(old_table, cls._table)
             migration_3_4 = True
 
         # Don't create table before renaming
@@ -488,7 +483,7 @@ class AnalyticMixin(object):
             entry = AccountEntry.__table__()
             table = cls.__table__()
             cursor.execute(*table.select(table.id, table.analytic_accounts,
-                    where=table.analytic_accounts != None))
+                    where=table.analytic_accounts != Null))
             for line_id, selection_id in cursor.fetchall():
                 cursor.execute(*entry.update(
                         columns=[entry.origin],
